@@ -1,6 +1,6 @@
 package App::Genpass;
 # ABSTRACT: Quickly and easily create secure passwords
-$App::Genpass::VERSION = '2.34';
+$App::Genpass::VERSION = '2.400';
 use Carp;
 use Moo;
 use Sub::Quote 'quote_sub';
@@ -10,6 +10,9 @@ use File::Spec;
 use Config::Any;
 use File::HomeDir;
 use List::AllUtils qw( any none shuffle );
+use Math::Random::Secure;
+
+sub _rand ($) { Math::Random::Secure::rand(shift) }
 
 has uppercase => (
     is      => 'ro',
@@ -232,7 +235,7 @@ _DIE_MSG
     }
 
     $length = $self->length
-            || $self->minlength + int(rand(abs($self->maxlength - $self->minlength) + 1));
+            || $self->minlength + int(_rand(abs($self->maxlength - $self->minlength) + 1));
 
     $number ||= $self->number;
 
@@ -243,7 +246,7 @@ _DIE_MSG
 
         # generating the password
         while ( $length > length $password ) {
-            my $char = $chars[ int rand @chars ];
+            my $char = $chars[ int _rand @chars ];
 
             # for verifying, we just check that it has small capital letters
             # if that doesn't work, we keep asking it to get a new random one
@@ -252,7 +255,7 @@ _DIE_MSG
                 # verify $char_type
                 if ( @{ $self->$char_type } ) {
                     while ( ! any { $_ eq $char } @{ $self->$char_type } ) {
-                        $char = $chars[ int rand @chars ];
+                        $char = $chars[ int _rand @chars ];
                     }
                 }
 
@@ -285,13 +288,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Genpass - Quickly and easily create secure passwords
 
 =head1 VERSION
 
-version 2.34
+version 2.400
 
 =head1 SYNOPSIS
 
@@ -451,8 +456,8 @@ After all the characters are set, unreadable characters will be removed from all
 sets.
 
 Thus, unreadable characters override all other sets. You can make unreadable
-characters not count by using the C<<readable => 0>> option, described by the
-I<readable> flag above.
+characters not count by using the C<< readable => 0 >> option, described by
+the I<readable> flag above.
 
 =item specials
 
@@ -478,14 +483,14 @@ to generate, defined by the attribute B<number> explained above.
 
 This method tries to be tricky and DWIM (or rather, DWYM). That is, if you
 request it to generate only one password and use scalar context
-(C<<my $p = $gp->generate(1)>>), it will return a single password.
+(C<< my $p = $gp->generate(1) >>), it will return a single password.
 
 However, if you try to generate multiple passwords and use scalar context
-(C<<my $p = $gp->generate(30)>>), it will return an array reference for the
+(C<< my $p = $gp->generate(30) >>), it will return an array reference for the
 passwords.
 
-Generating passwords with list context (C<<my @p = $gp->generate(...)>>) will
-always return a list of the passwords, even if it's a single password.
+Generating passwords with list context (C<< my @p = $gp->generate(...) >>)
+will always return a list of the passwords, even if it's a single password.
 
 =head2 get_config_from_file
 
